Contact
=======

You can get in touch with the developer & user community in any of the
following ways:

* Bug reports and feature requests: first read `contribution-guide.org
  <http://contribution-guide.org>`_, then check out our `GitHub page
  <https://github.com/pyinvoke/invoke>`_.
* IRC: ``#invoke`` on Freenode
* Twitter: you've got a few options here:

    * `@bitprophet <https://twitter.com/bitprophet>`_ is the canonical source
      for updates, but is also the developer's personal account (hint: you can
      turn off retweets and only see original content!)
    * `@pyfabric <https://twitter.com/pyfabric>`_ is a much lower-traffic,
      announcement-only account that also serves the `Fabric
      <http://fabfile.org>`_ project; given how much Fabric is built directly
      on top of Invoke, many of the posts will be relevant to Invoke-only
      users.
    * `@pyinvoke <https://twitter.com/pyinvoke>`_ was set up for
      Invoke-specific announcements, but it only has a dozen followers so we've
      unfortunately let it languish. Should we automate our release process
      further, this account may get posts again, and we'll update this page
      accordingly.

* Blog: TK
